.. image:: https://travis-ci.org/zopefoundation/Zope.svg?branch=master
        :target: https://travis-ci.org/zopefoundation/Zope

.. image:: https://coveralls.io/repos/github/zopefoundation/Zope/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/Zope?branch=master

.. image:: https://readthedocs.org/projects/zope/badge/?version=latest
        :target: https://zope.readthedocs.org/en/latest/
        :alt: Documentation Status

.. image:: https://img.shields.io/pypi/v/Zope.svg
        :target: https://pypi.org/project/Zope/
        :alt: Current version on PyPI

.. image:: https://img.shields.io/pypi/pyversions/Zope.svg
        :target: https://pypi.org/project/Zope/
        :alt: Supported Python versions

.. image:: https://requires.io/github/zopefoundation/Zope/requirements.svg?branch=master
        :target: https://requires.io/github/zopefoundation/Zope/requirements/?branch=master
        :alt: Requirements Status

.. contents::

Introduction
============

Zope is an open-source web application server.

This document provides some general information about Zope and provides
links to other documents.

Documentation can be found at https://zope.readthedocs.io.

Installation
============

You *cannot* simply do ``pip install Zope``, because you need
specific versions of all dependencies. Follow the documentation to
ensure you get the correct versions, or else installation is very
likely to fail. See https://zope.readthedocs.io/en/latest/INSTALL.html for
details.

License
=======

The Zope License is included in ``LICENSE.txt``.

Bug tracker
===========

Bugs reports should be made through the Zope bugtracker at
https://github.com/zopefoundation/Zope/issues.  A bug report should
contain detailed information about how to reproduce the bug.
